AreaChart class

An area chart widget.

Displays data as filled areas under lines. Supports stacked areas and gradients.

Inheritance

Constructors

AreaChart({required AreaChartData data, Key? key, ChartController? controller, ChartAnimation? animation, ChartInteractions interactions = const ChartInteractions(), TooltipConfig tooltip = const TooltipConfig(), void onDataPointTap(DataPointInfo info)?, void onDataPointHover(DataPointInfo? info)?, EdgeInsets padding = const EdgeInsets.fromLTRB(56, 24, 24, 48)})
const

Properties

animation ChartAnimation?
final
controller ChartController?
final
data AreaChartData
final
hashCode int
The hash code for this object.
no setterinherited
interactions ChartInteractions
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onDataPointHover → void Function(DataPointInfo? info)?
final
onDataPointTap → void Function(DataPointInfo info)?
final
padding EdgeInsets
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tooltip TooltipConfig
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<AreaChart>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited