BarSeries<X, Y extends num> class

A data series for bar charts.

Inheritance

Constructors

BarSeries({required List<DataPoint<X, Y>> data, String? name, Color? color, bool visible = true, Color? borderColor, double borderWidth = 0, BorderRadius borderRadius = const BorderRadius.vertical(top: Radius.circular(4)), Gradient? gradient})
const

Properties

borderColor Color?
Border color for the bars.
final
borderRadius BorderRadius
Border radius for the bars.
final
borderWidth double
Border width for the bars.
final
color Color?
The color for this series.
finalinherited
data List<DataPoint<X, Y>>
The data points in this series.
finalinherited
gradient Gradient?
Optional gradient fill for the bars.
final
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
Returns true if this series has no data points.
no setterinherited
isNotEmpty bool
Returns true if this series has data points.
no setterinherited
length int
The number of data points in this series.
no setterinherited
name String?
Optional name for this series (used in legends and tooltips).
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visible bool
Whether this series is visible.
finalinherited

Methods

copyWith({String? name, List<DataPoint<X, Y>>? data, Color? color, bool? visible, Color? borderColor, double? borderWidth, BorderRadius? borderRadius, Gradient? gradient}) BarSeries<X, Y>
Creates a copy of this series with the given values replaced.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValues<Y extends num>({required List<Y> values, String? name, Color? color, bool visible = true, Color? borderColor, double borderWidth = 0, BorderRadius borderRadius = const BorderRadius.vertical(top: Radius.circular(4)), Gradient? gradient}) BarSeries<int, Y>
Creates a BarSeries from a list of values with auto-generated x values.