CartesianChartConfig class

Base configuration for cartesian charts.

Constructors

CartesianChartConfig({EdgeInsets padding = const EdgeInsets.all(16), bool showXAxis = true, bool showYAxis = true, bool showGrid = true, AxisConfig? xAxisConfig, AxisConfig? yAxisConfig, GridConfig? gridConfig, double? xMin, double? xMax, double? yMin, double? yMax, bool includeZero = false})
const

Properties

gridConfig GridConfig?
Configuration for grid.
final
hashCode int
The hash code for this object.
no setterinherited
includeZero bool
Whether to include zero in Y axis.
final
padding EdgeInsets
Padding around the chart.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showGrid bool
Whether to show grid lines.
final
showXAxis bool
Whether to show the X axis.
final
showYAxis bool
Whether to show the Y axis.
final
xAxisConfig → AxisConfig?
Configuration for X axis.
final
xMax double?
Override maximum X value.
final
xMin double?
Override minimum X value.
final
yAxisConfig → AxisConfig?
Configuration for Y axis.
final
yMax double?
Override maximum Y value.
final
yMin double?
Override minimum Y value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited