report abstract method
Reports an error.
Subclasses should implement this to send errors to their service.
Implementation
FutureOr<void> report(ErrorReport report);
Reports an error.
Subclasses should implement this to send errors to their service.
FutureOr<void> report(ErrorReport report);