ChartPools class

Global pools for chart rendering.

These are shared across all charts for maximum efficiency.

Properties

hashCode int
The hash code for this object.
no setterinherited
paintPool PaintPool
final
pathPool PathPool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearAll() → void
Clears all pools (call when app is backgrounded).
createScope() PoolScope
Creates a new scope for automatic resource management.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance ChartPools
final