DataPointIndex class

Represents an index into a specific data point.

Annotations

Constructors

DataPointIndex(int seriesIndex, int pointIndex)
Creates a data point index.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
pointIndex int
The index of the point within the series.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seriesIndex int
The index of the series.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override