DefaultErrorReporter class

Default error reporter that logs errors using ChartLogger.

Inheritance

Constructors

DefaultErrorReporter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
report(ErrorReport report) → void
Reports an error.
override
reportChartException(ChartException exception, {StackTrace? stackTrace, ErrorContext? context, bool isFatal = false}) FutureOr<void>
Reports a chart exception.
inherited
reportError(Object error, {StackTrace? stackTrace, ErrorSeverity severity = ErrorSeverity.medium, ErrorContext? context, List<String>? tags, bool isFatal = false}) FutureOr<void>
Convenience method to report an error with context.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited