DumbbellChart class

A dumbbell chart widget.

Displays two connected points per category, useful for showing before/after comparisons or changes between two values.

Example:

DumbbellChart(
  data: DumbbellChartData(
    items: [
      DumbbellItem(label: '2020', startValue: 30, endValue: 50),
      DumbbellItem(label: '2021', startValue: 40, endValue: 65),
      DumbbellItem(label: '2022', startValue: 35, endValue: 70),
    ],
  ),
)
Inheritance

Constructors

DumbbellChart({required DumbbellChartData data, Key? key, ChartController? controller, ChartAnimation? animation, ChartInteractions interactions = const ChartInteractions(), TooltipConfig tooltip = const TooltipConfig(), void onItemTap(int index, DumbbellItem item)?, EdgeInsets padding = const EdgeInsets.all(24)})
const

Properties

animation ChartAnimation?
final
controller ChartController?
final
data DumbbellChartData
final
hashCode int
The hash code for this object.
no setterinherited
interactions ChartInteractions
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onItemTap → void Function(int index, DumbbellItem item)?
final
padding EdgeInsets
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tooltip TooltipConfig
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<DumbbellChart>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited