GanttResource class

Resource definition for resource-based views.

Annotations

Constructors

GanttResource({required String id, required String name, Color? color, double capacity = 1.0})
const

Properties

capacity double
Capacity (1.0 = full-time, 0.5 = half-time).
final
color Color?
Optional color for the resource's tasks.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier.
final
name String
Display name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited