LegendItem class

A single item in the legend.

Constructors

LegendItem({required String label, required Color color, MarkerShape shape = MarkerShape.square, bool isVisible = true, String? value, double? percentage})
const

Properties

color Color
Color representing this item.
final
hashCode int
The hash code for this object.
no setterinherited
isVisible bool
Whether this item is currently visible in the chart.
final
label String
Display label for this item.
final
percentage double?
Optional percentage to display.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape → MarkerShape
Shape of the legend marker.
final
value String?
Optional value to display.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited