PathPool class

Specialized pool for Path objects.

Constructors

PathPool({int maxSize = 50})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acquire() Path
Acquires a fresh path.
clear() → void
Clears the pool.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
release(Path path) → void
Releases a path back to the pool.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited