ResponsiveChartTheme class

Unified responsive theme provider for charts.

Combines responsive configuration, density settings, text scaling, focus indicators, and high contrast settings into a single provider.

Example:

ResponsiveChartTheme(
  child: MyChart(),
)

// Access in child widgets:
final theme = ResponsiveChartTheme.of(context);
final padding = theme.responsiveConfig.padding;
Inheritance

Constructors

ResponsiveChartTheme({required Widget child, Key? key, ResponsiveChartConfig? responsiveConfig, DensityConfig? densityConfig, TextScalingConfig? textScalingConfig, FocusIndicatorStyle? focusIndicatorStyle, HighContrastConfig? highContrastConfig})
const

Properties

child Widget
The child widget tree.
final
densityConfig DensityConfig?
Override density configuration.
final
focusIndicatorStyle FocusIndicatorStyle?
Override focus indicator style.
final
hashCode int
The hash code for this object.
no setterinherited
highContrastConfig HighContrastConfig?
Override high contrast configuration.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
responsiveConfig ResponsiveChartConfig?
Override responsive configuration.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textScalingConfig TextScalingConfig?
Override text scaling configuration.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

auto({required Widget child, bool detectHighContrast = true}) Widget
Creates theme with automatic configuration based on context.
maybeOf(BuildContext context) ResponsiveChartThemeData?
Gets the theme data from context, or null if not found.
of(BuildContext context) ResponsiveChartThemeData
Gets the complete theme data from context.