SankeyChartData class

Data configuration for Sankey chart.

Annotations

Constructors

SankeyChartData({required List<SankeyNode> nodes, required List<SankeyLink> links, double nodeWidth = 20.0, double nodePadding = 10.0, double linkOpacity = 0.4, bool showLabels = true, bool showValues = true, SankeyAlignment alignment = SankeyAlignment.justify, int iterations = 32, ChartAnimation? animation})
const

Properties

alignment SankeyAlignment
Node alignment.
final
animation ChartAnimation?
Animation configuration.
final
hashCode int
The hash code for this object.
no setterinherited
iterations int
Number of relaxation iterations for layout.
final
linkOpacity double
Opacity of links (0.0 to 1.0).
final
List of links between nodes.
final
nodePadding double
Vertical padding between nodes.
final
nodes List<SankeyNode>
List of nodes.
final
nodeWidth double
Width of node rectangles.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showLabels bool
Whether to show node labels.
final
showValues bool
Whether to show values on links.
final
totalValue double
Total value of all links.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited