SeriesPathKey class

Cache key for series paths.

Constructors

SeriesPathKey({required int seriesIndex, required int width, required int height, required int dataHash, String? curveType, double? strokeWidth})

Properties

curveType String?
final
dataHash int
final
hashCode int
The hash code for this object.
no setteroverride
height int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seriesIndex int
final
strokeWidth double?
final
width int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override