StepInterpolator class

Inheritance

Constructors

StepInterpolator({StepPosition position = StepPosition.after})

Properties

hashCode int
The hash code for this object.
no setterinherited
position StepPosition
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createPath(List<Offset> points) Path
Creates a path through the given points.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pointAt(List<Offset> points, double t) Offset
Gets a point on the interpolated curve at parameter t (0.0 to 1.0).
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited