TreemapChartData class

Data configuration for treemap chart.

Annotations

Constructors

TreemapChartData({required TreemapNode root, TreemapLayoutAlgorithm algorithm = TreemapLayoutAlgorithm.squarified, double padding = 2.0, double headerHeight = 0.0, TreemapBorderConfig border = const TreemapBorderConfig(), TreemapLabelPosition labelPosition = TreemapLabelPosition.topLeft, bool showLabels = true, double minLabelWidth = 30.0, double minLabelHeight = 20.0, bool colorByDepth = false, int? maxDepth, ChartAnimation? animation})
const

Properties

algorithm TreemapLayoutAlgorithm
Layout algorithm to use.
final
animation ChartAnimation?
Animation configuration.
final
border TreemapBorderConfig
Border configuration.
final
colorByDepth bool
Whether to color nodes by depth level.
final
hashCode int
The hash code for this object.
no setterinherited
headerHeight double
Height reserved for group headers.
final
labelPosition TreemapLabelPosition
Position of labels within nodes.
final
maxDepth int?
Maximum depth to render (null for all).
final
minLabelHeight double
Minimum height to show label.
final
minLabelWidth double
Minimum width to show label.
final
padding double
Padding between nodes (in pixels).
final
root TreemapNode
Root node of the treemap hierarchy.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showLabels bool
Whether to show labels.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited