BarSeriesConfig class
Configuration for bar series rendering.
- Inheritance
-
- Object
- SeriesConfig
- BarSeriesConfig
Constructors
-
BarSeriesConfig({bool visible = true, double animationProgress = 1.0, Color color = const Color(0xFF2196F3), List<
Color> ? colors, Color? borderColor, double borderWidth = 0.0, double cornerRadius = 6.0, BarOrientation orientation = BarOrientation.vertical, double? barWidth, double barWidthFraction = 0.8, List<Color> ? gradient, bool showValues = false, TextStyle? valueStyle, String valueFormatter(double value)?, double shadowElevation = 0, Color? shadowColor}) -
const
Properties
- animationProgress → double
-
Animation progress (0.0 to 1.0).
finalinherited
- barWidth → double?
-
Fixed bar width (null for auto).
final
- barWidthFraction → double
-
Fraction of available width for each bar (0.0 to 1.0).
final
- borderColor → Color?
-
Border color for bars.
final
- borderWidth → double
-
Border width for bars.
final
- color → Color
-
Default bar color.
final
-
colors
→ List<
Color> ? -
Colors for individual bars (overrides color).
final
- cornerRadius → double
-
Corner radius for bars.
final
-
gradient
→ List<
Color> ? -
Gradient for bars.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- orientation → BarOrientation
-
Bar orientation.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadowColor → Color?
-
Shadow color (defaults to black if null).
final
- shadowElevation → double
-
Shadow elevation for bars (0 means no shadow).
final
- showValues → bool
-
Whether to show values on bars.
final
- valueFormatter → String Function(double value)?
-
Custom value formatter.
final
- valueStyle → TextStyle?
-
Style for value labels.
final
- visible → bool
-
Whether this series is visible.
finalinherited
Methods
-
copyWith(
{bool? visible, double? animationProgress, Color? color, List< Color> ? colors, Color? borderColor, double? borderWidth, double? cornerRadius, BarOrientation? orientation, double? barWidth, double? barWidthFraction, List<Color> ? gradient, bool? showValues, TextStyle? valueStyle, String valueFormatter(double value)?, double? shadowElevation, Color? shadowColor}) → BarSeriesConfig - Creates a copy with updated values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited