BoxPlotChartData class
Data configuration for box plot chart.
- Annotations
Constructors
-
BoxPlotChartData({required List<
BoxPlotItem> items, BoxPlotOrientation orientation = BoxPlotOrientation.vertical, double boxWidth = 0.6, double whiskerWidth = 0.4, double strokeWidth = 1.5, bool showOutliers = true, double outlierRadius = 4, bool showMean = false, double meanMarkerSize = 6, bool showNotch = false, double notchWidth = 0.3, double fillOpacity = 0.3, ChartAnimation? animation}) -
const
Properties
- animation → ChartAnimation?
-
Animation configuration.
final
- boxWidth → double
-
Width of the box as ratio of available space.
final
- fillOpacity → double
-
Opacity of box fill.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
BoxPlotItem> -
List of box plot items.
final
- meanMarkerSize → double
-
Size of mean marker.
final
- notchWidth → double
-
Width of notch as ratio of box width.
final
- orientation → BoxPlotOrientation
-
Orientation of the boxes.
final
- outlierRadius → double
-
Radius of outlier markers.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showMean → bool
-
Whether to show mean marker.
final
- showNotch → bool
-
Whether to show notched boxes.
final
- showOutliers → bool
-
Whether to show outlier points.
final
- strokeWidth → double
-
Stroke width for outlines.
final
- whiskerWidth → double
-
Width of whiskers as ratio of box width.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited