PatternPainter class
Utility for applying patterns to chart elements.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createPatternShader(
ChartPattern pattern, Color color, Rect bounds, {double spacing = 8.0, double lineWidth = 2.0}) → Shader? - Creates a pattern shader for the given pattern type.
-
drawPattern(
Canvas canvas, Path clipPath, ChartPattern pattern, Color color, {double spacing = 8.0, double lineWidth = 2.0}) → void - Draws a pattern on the canvas within the given path.