PieSection class
A section in a pie/donut chart.
- Annotations
Constructors
Properties
- borderColor → Color?
-
Border color.
final
- borderWidth → double
-
Border width.
final
- color → Color?
-
Color for this section (uses theme color if null).
final
- explodeOffset → double
-
Offset when exploded (in pixels).
final
- gradient → Gradient?
-
Optional gradient fill for this section.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String?
-
Label for this section.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadowElevation → double
-
Shadow elevation for this section (0 = no shadow).
final
- value → double
-
The value of this section.
final
Methods
-
copyWith(
{double? value, String? label, Color? color, Color? borderColor, double? borderWidth, double? explodeOffset, Gradient? gradient, double? shadowElevation}) → PieSection -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited