PolarChartData class abstract
Data configuration for polar charts (radar).
Constructors
-
PolarChartData({ChartAnimation? animation, String? title, String? subtitle, List<
String> axisLabels = const [], double? maxValue, double minValue = 0.0, int tickCount = 5}) -
Creates polar chart data.
const
Properties
-
allSeries
→ List<
ChartSeries> -
The series contained in this chart data.
no setterinherited
- animation → ChartAnimation?
-
Animation configuration for this chart.
finalinherited
-
axisLabels
→ List<
String> -
Labels for each axis in the radar chart.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
Returns true if this chart data has no series or all series are empty.
no setterinherited
- isNotEmpty → bool
-
Returns true if this chart data has at least one non-empty series.
no setterinherited
- maxValue → double?
-
Maximum value for the axes (auto-calculated if null).
final
- minValue → double
-
Minimum value for the axes.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → String?
-
Optional chart subtitle.
finalinherited
- tickCount → int
-
Number of tick marks on each axis.
final
- title → String?
-
Optional chart title.
finalinherited
Methods
-
copyWith(
{ChartAnimation? animation, String? title, String? subtitle}) → ChartData -
Creates a copy of this chart data with the given values replaced.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited