PolarSeries<T extends DataPoint<dynamic, num> > class
abstract
Base class for polar chart series (radar).
- Inheritance
-
- Object
- ChartSeries<
T> - PolarSeries
- Annotations
Constructors
Properties
- color → Color?
-
The color for this series.
finalinherited
-
data
→ List<
T> -
The data points in this series.
finalinherited
- fillOpacity → double
-
The fill opacity for the area (0.0 to 1.0).
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isEmpty → bool
-
Returns true if this series has no data points.
no setterinherited
- isNotEmpty → bool
-
Returns true if this series has data points.
no setterinherited
- length → int
-
The number of data points in this series.
no setterinherited
- name → String?
-
Optional name for this series (used in legends and tooltips).
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strokeWidth → double
-
The stroke width for the line.
final
- visible → bool
-
Whether this series is visible.
finalinherited
Methods
-
copyWith(
{List< T> ? data, String? name, Color? color, bool? visible}) → ChartSeries<T> -
Creates a copy of this series with the given values replaced.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override