ScatterSeries<X, Y extends num> class
A data series for scatter charts.
Constructors
-
ScatterSeries({required List<
ScatterDataPoint< data, String? name, Color? color, bool visible = true, double pointSize = 8.0, ScatterPointShape pointShape = ScatterPointShape.circle, Color borderColor = Colors.white, double borderWidth = 1.5, double opacity = 1.0})X, Y> > -
const
Properties
- borderColor → Color
-
final
- borderWidth → double
-
final
- color → Color?
-
final
-
data
→ List<
ScatterDataPoint< X, Y> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
no setter
- length → int
-
no setter
- name → String?
-
final
- opacity → double
-
final
- pointShape → ScatterPointShape
-
final
- pointSize → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- visible → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited