TaskSchedule class
Scheduling result for a single task.
Constructors
Properties
- earlyFinish → DateTime
-
Earliest possible finish date.
final
- earlyStart → DateTime
-
Earliest possible start date.
final
- freeFloat → int
-
Free float in days.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCritical → bool
-
Whether this task is on the critical path.
final
- lateFinish → DateTime
-
Latest possible finish date without delaying the project.
final
- lateStart → DateTime
-
Latest possible start date without delaying the project.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- taskId → String
-
The task ID.
final
- totalFloat → int
-
Total float (slack) in days.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited