ZoomConfig class
Configuration for zoom behavior.
- Annotations
Constructors
- ZoomConfig({double minZoomX = 0.5, double maxZoomX = 20.0, double minZoomY = 0.5, double maxZoomY = 20.0, bool enablePinchZoom = true, bool enableScrollWheelZoom = true, bool enableDoubleTapZoom = true, double scrollWheelZoomFactor = 1.1, double doubleTapZoomFactor = 2.0, Duration animationDuration = const Duration(milliseconds: 300), Curve animationCurve = Curves.easeOutCubic})
-
Creates a zoom configuration.
const
Properties
- animationCurve → Curve
-
Curve for zoom animations.
final
- animationDuration → Duration
-
Duration of zoom animations.
final
- doubleTapZoomFactor → double
-
Zoom factor for double tap.
final
- enableDoubleTapZoom → bool
-
Whether double tap zoom is enabled.
final
- enablePinchZoom → bool
-
Whether pinch zoom is enabled.
final
- enableScrollWheelZoom → bool
-
Whether scroll wheel zoom is enabled.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxZoomX → double
-
Maximum zoom level for X axis.
final
- maxZoomY → double
-
Maximum zoom level for Y axis.
final
- minZoomX → double
-
Minimum zoom level for X axis.
final
- minZoomY → double
-
Minimum zoom level for Y axis.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollWheelZoomFactor → double
-
Zoom factor for scroll wheel.
final
Methods
-
copyWith(
{double? minZoomX, double? maxZoomX, double? minZoomY, double? maxZoomY, bool? enablePinchZoom, bool? enableScrollWheelZoom, bool? enableDoubleTapZoom, double? scrollWheelZoomFactor, double? doubleTapZoomFactor, Duration? animationDuration, Curve? animationCurve}) → ZoomConfig - Creates a copy with the given values replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- financial → const ZoomConfig
- Configuration for financial charts (more zoom range).
- standard → const ZoomConfig
- Standard zoom configuration.
- touchOnly → const ZoomConfig
- Configuration for touch-only devices.